@@ -98,7 +98,7 @@ uint32_t static inline fillHtOne(struct ht *Q,int N,int *in,int *out,int mixOff)
  for(int e=0;e<N;e++){
   if(in[e]==NA_INTEGER) error("NA values are not allowed");
   uint64_t _ab=(uint64_t)(in[e]);
-  uint32_t hab=_ab%N;//TODO: Better hash?
+  uint32_t hab=_ab%N;
 
   struct hte **E;
   for(E=Q->map+hab;E[0] && E[0]->ab!=_ab;E=&(E[0]->nxt));
@@ -114,28 +114,6 @@ uint32_t static inline fillHtOne(struct ht *Q,int N,int *in,int *out,int mixOff)
  return(nAB);
 }
 
-uint32_t static inline fillHtOneCounting(struct ht *Q,int N,int *in){
- uint32_t nAB=0;
- for(int e=0;e<N;e++) Q->map[e]=NULL;
- //TODO: Ht is likely not needed here
- for(int e=0;e<N;e++){
-  uint64_t _ab=(uint64_t)(in[e]);
-  uint32_t hab=_ab%N;//TODO: Better hash?
-
-  struct hte **E;
-  for(E=Q->map+hab;(*E)&&(*E)->ab!=_ab;E=&((*E)->nxt));
-
-  if(!*E){
-   Q->cnt[nAB].ab=_ab;
-   Q->cnt[nAB].nxt=NULL;
-   Q->cnt[nAB].c=1;
-   *E=Q->cnt+nAB;
-   nAB++;
-  }else (*E)->c++;
- }
- return(Q->nAB=nAB);
-}
-
 double miHt(struct ht *Q,int *cA,int *cB){
  double ans=0.,N=Q->N;
  for(int e=0;e<Q->nAB;e++){
@@ -158,17 +136,47 @@ double nmiHt(struct ht *Q,int *cA,int *cB){
   I+=cAB*log((cAB*N)/(_cA*_cB));
   H+=-cAB*log(cAB/N);
  }
+ // NaN when I=H=0 is expected
  return(I/H);
 }
 
-double hHt(struct ht *Q){
- double H=0.,N=Q->N;
+//Note translation vectors are zero-based, i.e. one must subtract
+// mixOff like mix2a[mix[e]-mixOff]-> a (in original offset)
+void transHt(struct ht *Q,int *mix2a,int *mix2b){
+ for(int e=0;e<Q->nAB;e++){
+  if(mix2a)
+   mix2a[e]=GET_A(Q->cnt[e].ab);
+  if(mix2b)
+   mix2b[e]=GET_B(Q->cnt[e].ab);
+ }
+}
+
+void mixCountsHt(struct ht *Q,int *c){
+ for(int e=0;e<Q->nAB;e++)
+  c[e]=Q->cnt[e].c;
+}
+
+double cmiHt(struct ht *Q,int *cXW,int *cYW,int *yw2w,int *cW){
+ double I=0.,N=Q->N;
  for(int e=0;e<Q->nAB;e++){
   if(!(Q->cnt[e].c)) continue;
-  double cAB=Q->cnt[e].c;
-  H+=-cAB*log(cAB/N);
+  double _cXYW=((double)Q->cnt[e].c),
+   _cXW=cXW[GET_A(Q->cnt[e].ab)],
+   _cYW=cYW[GET_B(Q->cnt[e].ab)],
+   _cW=cW[yw2w[GET_B(Q->cnt[e].ab)]];
+  I+=_cXYW*log(_cXYW*_cW/_cXW/_cYW);
  }
- return(H/N);
+ return(I/N);
+}
+
+double hC(int n,int nc,int *c){
+ double H=0.,N=n;
+ for(int e=0;e<nc;e++) 
+  if(c[e]){
+   double C=c[e];
+   H+=-C*log(C/N);
+  }
+ return(H/((double)n));
 }
 
 //Impurity is calculated in two parts,
