@@ -51,6 +51,10 @@
 
 #include "kt.h"
 
+//TSP transformation
+
+#include "tsp.h"
+
 //Auxiliary
 
 #include "side.h"
@@ -90,6 +94,7 @@ static const R_CallMethodDef R_CallDef[]={
  CALLDEF(C_JIM,4),
  CALLDEF(C_kt,1),
  CALLDEF(C_rkt,1),
+ CALLDEF(C_tsp,3),
  CALLDEF(C_join,1),
  CALLDEF(C_tri,2),
  {NULL,NULL,0}
